@@ -1,7 +1,7 @@
-from multiprocessing import Queue
+from multiprocessing import Pool, Queue
 from typing import Optional
 
-__version__ = "0.0.16"
+__version__ = "0.0.21"
 
 import copy
 import time
@@ -24,6 +24,9 @@ class Monitor:
     def time_in_queue(self, tnq: int):
         pass
 
+    def track_time_in_pool(self, nano_seconds: int):
+        pass
+
 
 class MNQueue:
     def __init__(self, monitor: Optional[Monitor] = None, maxsize=0):
@@ -76,26 +79,31 @@ class MNQueue:
 
         return rc
 
-    def qsize(self):
-        return self.queue.qsize()
+    def __getattr__(self, attr):
+        if attr not in self.__dict__:
+            return self.queue.__getattribute__(attr)
 
-    def empty(self):
-        return self.queue.empty()
 
-    def full(self):
-        return self.queue.full()
+class MNPool:
+    def __init__(self, *args, monitor=None, **kwargs):
+        self.monitor = monitor
+        self.pool: Pool = Pool(*args, **kwargs)
+        self.tnp: int
 
-    def get_nowait(self):
-        return self.get(False)
+    def __getattr__(self, attr):
+        if attr not in self.__dict__:
+            return self.pool.__getattribute__(attr)
 
-    def put_nowait(self, obj):
-        return self.put(obj, False)
+    def __enter__(self):
+        if self.monitor:
+            self.tnp = time.time_ns()
 
-    def close(self):
-        self.queue.close()
+        return self.pool.__enter__()
 
-    def join_thread(self):
-        self.queue.join_thread()
+    def __exit__(self, exc_type, exc_val, exc_tb):
+        _exit = self.pool.__exit__(exc_type, exc_val, exc_tb)
 
-    def cancel_join_thread(self):
-        self.queue.cancel_join_thread()
+        if self.monitor:
+            self.monitor.track_time_in_pool(time.time_ns() - self.tnp)
+
+        return _exit
